@@ -26,7 +26,7 @@ use warnings;
 
 package CAD::Firemen::ParseHelp::Creo3;
 {
-  $CAD::Firemen::ParseHelp::Creo3::VERSION = '0.7.1';
+  $CAD::Firemen::ParseHelp::Creo3::VERSION = '0.7.2';
 }
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -91,12 +91,15 @@ sub findOptionPage {
   print "\n";
 
   my $jsonContent = parse_json($json);
+  if(!$jsonContent || !exists($jsonContent->{"words"}) || !exists($jsonContent->{"pages"})){
+    return (0, "Could not parse content of ". $file);
+  }
 
-  my $items = scalar(keys($jsonContent->{"words"}));
-  $progress = Term::ProgressBar->new({name => "Processing ". scalar(keys($jsonContent->{"words"})) ." keywords and ". scalar(keys($jsonContent->{"pages"})) ." pages for app ". $app, count => $items});
+  my $items = scalar(keys(%{$jsonContent->{"words"}}));
+  $progress = Term::ProgressBar->new({name => "Processing ". $items ." keywords and ". scalar(keys(@{$jsonContent->{"pages"}})) ." pages for app ". $app, count => $items});
   $progress->minor(0);
   $i = 0;
-  foreach my $key (keys($jsonContent->{"words"})){
+  foreach my $key (keys(%{$jsonContent->{"words"}})){
     foreach my $option (keys(%{$cdbOptions})){
       if(!exists($optionsInfo->{$option})){
         if($key =~ m/$option/i){
@@ -304,7 +307,7 @@ CAD::Firemen::ParseHelp::Creo3 - Shared functions to exctract options and their
 
 =head1 VERSION
 
-version 0.7.1
+version 0.7.2
 
 =head1 METHODS
 
